#
# spec file for package cosmic-notifications
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.system76.CosmicNotifications
Name:           cosmic-notifications
Version:        1.0.0~alpha7+0
Release:        1.1
Summary:        Layer for COSMIC Notifications
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-notifications
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Patch0:         switch-to-mold.patch
BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  just
BuildRequires:  mold
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xkbcommon)

%description
Layer Shell notifications daemon which integrates with COSMIC.

%prep
%autosetup -p1 -a1

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install

%check
%{cargo_test}

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{appname}.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml

%changelog
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+0:
  * i18n - update portuguese translations (#76)
  * i18n(nl) add/update Dutch translation (#75)
  * Add Hungarian translations (#65)
  * i18n(fr): Add French translation (#32)
  * Create cosmic_notifications.ftl (#38)
  * i18n(hu): Add Hungarian translation (#39)
  * fix(l18n): Ensure COSMIC is properly cased (#51)
  * add Dutch translation (#59)
  * Add Polish translation to metainfo (#63)
  * i18n (pt-BR) Update translation (#71)
  * Add Italian translation (#73)
  * i18n(ro): Add Romanian translation (#74)
  * fix: freeze in Firefox when notifications are received
  * fix: define rust 1.85.1 in toolchain to force rustup to update
  * chore: filter cosmic-config errors that need not be logged
  * chore: Rust 2024 edition
  * chore: upgrade all dependencies / fix clippy warnings
  * chore: update libcosmic
  * fix(libcosmic): theme subscription
  * fix license references
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * chore: update libcosmic
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+0:
  * perf: optimized cosmic-freedesktop-icons
  * update freedesktop-icons
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+1:
  * update deps
  * cleanup
  * feat: applet notification actions
  * feat: allow activation of notifications
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * update libcosmic
  * chore: update deps
  * update iced
  * Make failure to connect to journald a warning, not a hard error
  * Add a defaulted systemd feature to include and use tracing_journald
  * chore: update deps
  * Add zh-TW translation
  * support CARGO_TARGET_DIR
  * fix: set caps for timeout and notification list
  * cleanup
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * Add a defaulted systemd feature to include and use tracing_journald
  * Make failure to connect to journald a warning, not a hard error
  * update dependencies
- require rust >= 1.80
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * update dependencies
- enable leap (thanks to vyvir)
* Thu Mar 14 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
